==================
WAR2MAFF converter
==================

.. image:: https://secure.travis-ci.org/mcepl/war2maff.png
   :alt: Build Status

Convert web archives generated by konqueror_ to MAFF_ format accepted by
Mozilla addon_.

.. _konqueror:
    https://konqueror.org/
.. _MAFF:
    http://maf.mozdev.org/maff-file-format.html
.. _addon:
    https://addons.mozilla.org/en-US/firefox/addon/mozilla-archive-format/
